@@ -9,7 +9,6 @@ import pyarrow.parquet as pq
 import urllib.request
 from typing import Any, Dict
 
-# Location of biobricks
 BASE_DIR = os.path.expanduser('~')+'/biobricks'
 CONFIG_FILE = BASE_DIR+'/config.json'
 config = None
@@ -79,9 +78,11 @@ def load(brick):
             print(f"Can't load brick {brick}.")
             return None
     print(f"Loading brick {brick} from local library.")
-    repo = "biobricks-ai/"+brick
-    repodir = library+"/"+repo
-    return pq.read_table(repodir)
+    brickpq = "biobricks-ai/"+brick+"/brick"
+    return pq.read_table(brickpq)
 
 def remove(brick):
     global library, config, bricks
+
+def listbricks():
+    print(bricks)
